Crate koto_serde

Crate koto_serde 

Serde serialization and deserialization support for Koto value types

Structs

DeserializableKValue
A newtype for KValue that implements serde::Deserialize
Deserializer
SerializableKValue
A newtype for KValue that implements serde::Serialize
Serializer
A serializer that produces KValues

Enums

Error
The error type used when serializing to or from KValues

Functions

from_koto_value
Deserializes a KValue into a type that implements Deserialize
to_koto_value
Serializes a value into a KValue

Type Aliases

Result
The result type used when serializing to or from KValues